From 10fee18f0862a31ec11bf863ba7e0592c2148271 Mon Sep 17 00:00:00 2001
From: Gleb Pinigin <gpinigin@gmail.com>
Date: Tue, 19 Feb 2013 22:34:55 +0700
Subject: [PATCH 1/2] [iOS]Implement ability to play video on external display
 connected via cable or AirPlay Mirroring

---
 Classes/MVLCMovieViewController.h  |   3 +
 Classes/MVLCMovieViewController.m  |  84 ++++++++++++++++++-
 Resources/MVLCMovieView~ipad.xib   | 165 ++++++++++++++++++++++++++++++++++---
 Resources/MVLCMovieView~iphone.xib | 164 +++++++++++++++++++++++++++++++++---
 4 files changed, 395 insertions(+), 21 deletions(-)

diff --git a/Classes/MVLCMovieViewController.h b/Classes/MVLCMovieViewController.h
index 0a72895..fef92fd 100644
--- a/Classes/MVLCMovieViewController.h
+++ b/Classes/MVLCMovieViewController.h
@@ -41,6 +41,9 @@
 @property (nonatomic, retain) IBOutlet UIButton * trackSelectorButton;
 @property (nonatomic, retain) IBOutlet UIBarButtonItem * doneBarButton;
 @property (nonatomic, assign) BOOL hudVisibility;
+
+@property (nonatomic, retain) IBOutlet UIView *playingExternallyView;
+
 - (IBAction)toggleHUDVisibility:(id)sender;
 - (IBAction)togglePlayOrPause:(id)sender;
 - (IBAction)position:(id)sender;
diff --git a/Classes/MVLCMovieViewController.m b/Classes/MVLCMovieViewController.m
index 09c96c1..2efc4e0 100644
--- a/Classes/MVLCMovieViewController.m
+++ b/Classes/MVLCMovieViewController.m
@@ -11,11 +11,39 @@
 
 #import "MVLCMovieViewController.h"
 
+@interface ExternalDisplayController : UIViewController
+@end
+
+@implementation ExternalDisplayController
+
+- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation {
+    return NO;
+}
+
+- (BOOL)shouldAutorotate {
+    return NO;
+}
+
+- (NSUInteger)supportedInterfaceOrientations {
+    return ~UIInterfaceOrientationMaskAll;
+}
+
+@end
+
+
+@interface MVLCMovieViewController ()
+
+@property (nonatomic, retain) UIWindow *externalWindow;
+
+@end
+
 static NSString * MVLCMovieViewControllerHUDFadeInAnimation = @"MVLCMovieViewControllerHUDFadeInAnimation";
 static NSString * MVLCMovieViewControllerHUDFadeOutAnimation = @"MVLCMovieViewControllerHUDFadeOutAnimation";
 
 @implementation MVLCMovieViewController
 @synthesize movieView=_movieView, file=_file, url=_url, positionSlider=_positionSlider, playOrPauseButton=_playOrPauseButton, volumeSlider=_volumeSlider, HUDView=_HUDView, topView=_topView, remainingTimeLabel=_remainingTimeLabel, trackSelectorButton=_trackSelectorButton, doneBarButton=_doneBarButton;
+@synthesize externalWindow = _externalWindow, playingExternallyView = _playingExternallyView;
+
 
 - (id)init {
     self = [super initWithNibName:@"MVLCMovieView" bundle:nil];
@@ -35,9 +63,18 @@ static NSString * MVLCMovieViewControllerHUDFadeOutAnimation = @"MVLCMovieViewCo
     [tapGestureRecognizer release];
     self.doneBarButton.title = NSLocalizedString(@"Done", @"playback tab bar");
 
-    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(appWillResign:) name:UIApplicationWillResignActiveNotification object:nil];
+    NSNotificationCenter *center = [NSNotificationCenter defaultCenter];
+    [center addObserver:self selector:@selector(appWillResign:) name:UIApplicationWillResignActiveNotification object:nil];
+    [center addObserver:self selector:@selector(handleExternalScreenDidConnect:)
+                   name:UIScreenDidConnectNotification object:nil];
+    [center addObserver:self selector:@selector(handleExternalScreenDidDisconnect:)
+                   name:UIScreenDidDisconnectNotification object:nil];
 
     _hudVisibility = YES;
+    
+    if ([self hasExternalDisplay]) {
+        [self showOnExternalDisplay];
+    }
 //    [self setHudVisibility:NO]; // This triggers a bug in the transition animation on the iPhone
 }
 
@@ -105,6 +142,10 @@ static NSString * MVLCMovieViewControllerHUDFadeOutAnimation = @"MVLCMovieViewCo
     [_mediaPlayer release];
     [_url release];
     [_file release];
+    [_externalWindow release];
+    [_playingExternallyView release];
+    [[NSNotificationCenter defaultCenter] removeObserver:self];
+    
     [super dealloc];
 }
 
@@ -301,4 +342,45 @@ static NSString * MVLCMovieViewControllerHUDFadeOutAnimation = @"MVLCMovieViewCo
     }
     [_mediaPlayer setCurrentAudioTrackIndex: buttonIndex];
 }
+
+#pragma mark - external display
+
+- (BOOL)hasExternalDisplay {
+    return ([[UIScreen screens] count] > 1);
+}
+
+- (void)showOnExternalDisplay {
+    UIScreen *screen = [[UIScreen screens] objectAtIndex:1];
+    screen.overscanCompensation = UIScreenOverscanCompensationInsetApplicationFrame;
+    
+    self.externalWindow = [[[UIWindow alloc] initWithFrame:screen.bounds] autorelease];
+    UIViewController *controller = [[[ExternalDisplayController alloc] init] autorelease];
+    self.externalWindow.rootViewController = controller;
+    [controller.view addSubview:_movieView];
+    controller.view.frame = screen.bounds;
+    _movieView.frame = screen.bounds;
+    self.playingExternallyView.hidden = NO;
+   
+    self.externalWindow.screen = screen;
+    self.externalWindow.hidden = NO;
+}
+
+- (void)hideFromExternalDisplay {
+    [self.view addSubview:_movieView];
+    [self.view sendSubviewToBack:_movieView];
+    _movieView.frame = self.view.frame;
+    self.playingExternallyView.hidden = YES;
+    
+    self.externalWindow.hidden = YES;
+    self.externalWindow = nil;
+}
+
+- (void)handleExternalScreenDidConnect:(NSNotification *)notification {
+    [self showOnExternalDisplay];
+}
+
+- (void)handleExternalScreenDidDisconnect:(NSNotification *)notification {
+    [self hideFromExternalDisplay];
+}
+
 @end
diff --git a/Resources/MVLCMovieView~ipad.xib b/Resources/MVLCMovieView~ipad.xib
index 9e4fc94..11345ca 100644
--- a/Resources/MVLCMovieView~ipad.xib
+++ b/Resources/MVLCMovieView~ipad.xib
@@ -15,6 +15,7 @@
 			<string>IBUIBarButtonItem</string>
 			<string>IBUIButton</string>
 			<string>IBUIImageView</string>
+			<string>IBUILabel</string>
 			<string>IBUISlider</string>
 			<string>IBUIToolbar</string>
 			<string>IBUIView</string>
@@ -42,10 +43,11 @@
 					<object class="IBUIView" id="1069699796">
 						<reference key="NSNextResponder" ref="191373211"/>
 						<int key="NSvFlags">274</int>
+						<array class="NSMutableArray" key="NSSubviews"/>
 						<string key="NSFrameSize">{768, 1004}</string>
 						<reference key="NSSuperview" ref="191373211"/>
 						<reference key="NSWindow"/>
-						<reference key="NSNextKeyView" ref="720789294"/>
+						<reference key="NSNextKeyView" ref="691950689"/>
 						<object class="NSColor" key="IBUIBackgroundColor">
 							<int key="NSColorSpace">1</int>
 							<bytes key="NSRGB">MCAwIDAAA</bytes>
@@ -53,6 +55,110 @@
 						</object>
 						<string key="targetRuntimeIdentifier">IBIPadFramework</string>
 					</object>
+					<object class="IBUIView" id="691950689">
+						<reference key="NSNextResponder" ref="191373211"/>
+						<int key="NSvFlags">-2147483347</int>
+						<array class="NSMutableArray" key="NSSubviews">
+							<object class="IBUIImageView" id="995120440">
+								<reference key="NSNextResponder" ref="691950689"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{51, 0}, {298, 266}}</string>
+								<reference key="NSSuperview" ref="691950689"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="466766809"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<int key="IBUIContentMode">4</int>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBIPadFramework</string>
+								<object class="NSCustomResource" key="IBUIImage">
+									<string key="NSClassName">NSImage</string>
+									<string key="NSResourceName">MVLCNoMediaImage.png</string>
+								</object>
+							</object>
+							<object class="IBUILabel" id="466766809">
+								<reference key="NSNextResponder" ref="691950689"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{51, 274}, {298, 21}}</string>
+								<reference key="NSSuperview" ref="691950689"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="217600684"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<object class="NSColor" key="IBUIBackgroundColor" id="711731296">
+									<int key="NSColorSpace">3</int>
+									<bytes key="NSWhite">MCAwAA</bytes>
+								</object>
+								<bool key="IBUIOpaque">NO</bool>
+								<bool key="IBUIClipsSubviews">YES</bool>
+								<int key="IBUIContentMode">7</int>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBIPadFramework</string>
+								<string key="IBUIText">TV Connected</string>
+								<object class="NSColor" key="IBUITextColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkAA</bytes>
+								</object>
+								<nil key="IBUIHighlightedColor"/>
+								<int key="IBUIBaselineAdjustment">0</int>
+								<int key="IBUITextAlignment">1</int>
+								<object class="IBUIFontDescription" key="IBUIFontDescription">
+									<int key="type">2</int>
+									<double key="pointSize">19</double>
+								</object>
+								<object class="NSFont" key="IBUIFont">
+									<string key="NSName">Helvetica-Bold</string>
+									<double key="NSSize">19</double>
+									<int key="NSfFlags">16</int>
+								</object>
+								<bool key="IBUIAdjustsFontSizeToFit">NO</bool>
+							</object>
+							<object class="IBUILabel" id="217600684">
+								<reference key="NSNextResponder" ref="691950689"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{51, 303}, {298, 53}}</string>
+								<reference key="NSSuperview" ref="691950689"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="720789294"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<reference key="IBUIBackgroundColor" ref="711731296"/>
+								<bool key="IBUIOpaque">NO</bool>
+								<bool key="IBUIClipsSubviews">YES</bool>
+								<int key="IBUIContentMode">7</int>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBIPadFramework</string>
+								<string key="IBUIText">Video is playing on TV</string>
+								<object class="NSColor" key="IBUITextColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkAA</bytes>
+								</object>
+								<object class="NSColor" key="IBUIHighlightedColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkgMC44MQA</bytes>
+								</object>
+								<int key="IBUIBaselineAdjustment">0</int>
+								<int key="IBUINumberOfLines">0</int>
+								<int key="IBUITextAlignment">1</int>
+								<object class="IBUIFontDescription" key="IBUIFontDescription">
+									<int key="type">1</int>
+									<double key="pointSize">16</double>
+								</object>
+								<object class="NSFont" key="IBUIFont">
+									<string key="NSName">Helvetica</string>
+									<double key="NSSize">16</double>
+									<int key="NSfFlags">16</int>
+								</object>
+								<bool key="IBUIAdjustsFontSizeToFit">NO</bool>
+								<double key="preferredMaxLayoutWidth">298</double>
+							</object>
+						</array>
+						<string key="NSFrame">{{184, 247}, {400, 400}}</string>
+						<reference key="NSSuperview" ref="191373211"/>
+						<reference key="NSWindow"/>
+						<reference key="NSNextKeyView" ref="995120440"/>
+						<string key="NSReuseIdentifierKey">_NS:9</string>
+						<reference key="IBUIBackgroundColor" ref="711731296"/>
+						<bool key="IBUIUserInteractionEnabled">NO</bool>
+						<string key="targetRuntimeIdentifier">IBIPadFramework</string>
+					</object>
 					<object class="IBUIView" id="248075313">
 						<reference key="NSNextResponder" ref="191373211"/>
 						<int key="NSvFlags">269</int>
@@ -64,10 +170,7 @@
 								<reference key="NSSuperview" ref="248075313"/>
 								<reference key="NSWindow"/>
 								<reference key="NSNextKeyView" ref="1017172956"/>
-								<object class="NSColor" key="IBUIBackgroundColor" id="711731296">
-									<int key="NSColorSpace">3</int>
-									<bytes key="NSWhite">MCAwAA</bytes>
-								</object>
+								<reference key="IBUIBackgroundColor" ref="711731296"/>
 								<bool key="IBUIOpaque">NO</bool>
 								<bool key="IBUIUserInteractionEnabled">NO</bool>
 								<string key="targetRuntimeIdentifier">IBIPadFramework</string>
@@ -268,10 +371,7 @@
 				<reference key="NSNextKeyView" ref="1069699796"/>
 				<object class="NSColor" key="IBUIBackgroundColor">
 					<int key="NSColorSpace">3</int>
-					<bytes key="NSWhite">MQA</bytes>
-					<object class="NSColorSpace" key="NSCustomColorSpace">
-						<int key="NSID">2</int>
-					</object>
+					<bytes key="NSWhite">MAA</bytes>
 				</object>
 				<object class="IBUISimulatedStatusBarMetrics" key="IBUISimulatedStatusBarMetrics">
 					<int key="IBUIStatusBarStyle">2</int>
@@ -354,6 +454,14 @@
 					<int key="connectionID">62</int>
 				</object>
 				<object class="IBConnectionRecord">
+					<object class="IBCocoaTouchOutletConnection" key="connection">
+						<string key="label">playingExternallyView</string>
+						<reference key="source" ref="372490531"/>
+						<reference key="destination" ref="691950689"/>
+					</object>
+					<int key="connectionID">67</int>
+				</object>
+				<object class="IBConnectionRecord">
 					<object class="IBCocoaTouchEventConnection" key="connection">
 						<string key="label">togglePlayOrPause:</string>
 						<reference key="source" ref="594951421"/>
@@ -422,6 +530,7 @@
 							<reference ref="248075313"/>
 							<reference ref="1069699796"/>
 							<reference ref="720789294"/>
+							<reference ref="691950689"/>
 						</array>
 						<reference key="parent" ref="0"/>
 					</object>
@@ -522,6 +631,32 @@
 						<reference key="object" ref="1017172956"/>
 						<reference key="parent" ref="248075313"/>
 					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">63</int>
+						<reference key="object" ref="691950689"/>
+						<array class="NSMutableArray" key="children">
+							<reference ref="217600684"/>
+							<reference ref="466766809"/>
+							<reference ref="995120440"/>
+						</array>
+						<reference key="parent" ref="191373211"/>
+						<string key="objectName">Playing Externally View</string>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">66</int>
+						<reference key="object" ref="217600684"/>
+						<reference key="parent" ref="691950689"/>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">65</int>
+						<reference key="object" ref="466766809"/>
+						<reference key="parent" ref="691950689"/>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">64</int>
+						<reference key="object" ref="995120440"/>
+						<reference key="parent" ref="691950689"/>
+					</object>
 				</array>
 			</object>
 			<dictionary class="NSMutableDictionary" key="flattenedProperties">
@@ -543,6 +678,10 @@
 				<string key="57.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="58.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="6.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="63.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="64.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="65.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="66.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="8.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="9.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 			</dictionary>
@@ -550,7 +689,7 @@
 			<nil key="activeLocalization"/>
 			<dictionary class="NSMutableDictionary" key="localizations"/>
 			<nil key="sourceID"/>
-			<int key="maxID">62</int>
+			<int key="maxID">67</int>
 		</object>
 		<object class="IBClassDescriber" key="IBDocument.Classes">
 			<array class="NSMutableArray" key="referencedPartialClassDescriptions">
@@ -614,6 +753,7 @@
 						<string key="doneBarButton">UIBarButtonItem</string>
 						<string key="movieView">UIView</string>
 						<string key="playOrPauseButton">UIButton</string>
+						<string key="playingExternallyView">UIView</string>
 						<string key="positionSlider">UISlider</string>
 						<string key="remainingTimeLabel">UIBarItem</string>
 						<string key="topView">UIView</string>
@@ -637,6 +777,10 @@
 							<string key="name">playOrPauseButton</string>
 							<string key="candidateClassName">UIButton</string>
 						</object>
+						<object class="IBToOneOutletInfo" key="playingExternallyView">
+							<string key="name">playingExternallyView</string>
+							<string key="candidateClassName">UIView</string>
+						</object>
 						<object class="IBToOneOutletInfo" key="positionSlider">
 							<string key="name">positionSlider</string>
 							<string key="candidateClassName">UISlider</string>
@@ -694,6 +838,7 @@
 			<string key="MVLCMovieViewHUDFastForward~ipad.png">{37, 25}</string>
 			<string key="MVLCMovieViewHUDPlay~ipad.png">{27, 30}</string>
 			<string key="MVLCMovieViewHUDRewind~ipad.png">{37, 25}</string>
+			<string key="MVLCNoMediaImage.png">{262, 196}</string>
 		</dictionary>
 		<string key="IBCocoaTouchPluginVersion">2083</string>
 	</data>
diff --git a/Resources/MVLCMovieView~iphone.xib b/Resources/MVLCMovieView~iphone.xib
index 8e50138..8fcb891 100644
--- a/Resources/MVLCMovieView~iphone.xib
+++ b/Resources/MVLCMovieView~iphone.xib
@@ -15,6 +15,7 @@
 			<string>IBUIBarButtonItem</string>
 			<string>IBUIButton</string>
 			<string>IBUIImageView</string>
+			<string>IBUILabel</string>
 			<string>IBUISlider</string>
 			<string>IBUIToolbar</string>
 			<string>IBUIView</string>
@@ -42,10 +43,11 @@
 					<object class="IBUIView" id="1066569913">
 						<reference key="NSNextResponder" ref="191373211"/>
 						<int key="NSvFlags">274</int>
+						<array class="NSMutableArray" key="NSSubviews"/>
 						<string key="NSFrameSize">{320, 460}</string>
 						<reference key="NSSuperview" ref="191373211"/>
 						<reference key="NSWindow"/>
-						<reference key="NSNextKeyView" ref="557375485"/>
+						<reference key="NSNextKeyView" ref="629468800"/>
 						<object class="NSColor" key="IBUIBackgroundColor">
 							<int key="NSColorSpace">1</int>
 							<bytes key="NSRGB">MCAwIDAAA</bytes>
@@ -53,6 +55,109 @@
 						</object>
 						<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
 					</object>
+					<object class="IBUIView" id="629468800">
+						<reference key="NSNextResponder" ref="191373211"/>
+						<int key="NSvFlags">-2147483347</int>
+						<array class="NSMutableArray" key="NSSubviews">
+							<object class="IBUIImageView" id="417847988">
+								<reference key="NSNextResponder" ref="629468800"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{80, 20}, {160, 130}}</string>
+								<reference key="NSSuperview" ref="629468800"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="351293636"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
+								<object class="NSCustomResource" key="IBUIImage">
+									<string key="NSClassName">NSImage</string>
+									<string key="NSResourceName">MVLCNoMediaImage.png</string>
+								</object>
+							</object>
+							<object class="IBUILabel" id="351293636">
+								<reference key="NSNextResponder" ref="629468800"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{20, 170}, {280, 21}}</string>
+								<reference key="NSSuperview" ref="629468800"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="277270157"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<object class="NSColor" key="IBUIBackgroundColor" id="172308136">
+									<int key="NSColorSpace">3</int>
+									<bytes key="NSWhite">MCAwAA</bytes>
+								</object>
+								<bool key="IBUIOpaque">NO</bool>
+								<bool key="IBUIClipsSubviews">YES</bool>
+								<int key="IBUIContentMode">7</int>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
+								<string key="IBUIText">TV Connected</string>
+								<object class="NSColor" key="IBUITextColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkAA</bytes>
+								</object>
+								<nil key="IBUIHighlightedColor"/>
+								<int key="IBUIBaselineAdjustment">0</int>
+								<int key="IBUITextAlignment">1</int>
+								<object class="IBUIFontDescription" key="IBUIFontDescription">
+									<int key="type">2</int>
+									<double key="pointSize">19</double>
+								</object>
+								<object class="NSFont" key="IBUIFont">
+									<string key="NSName">Helvetica-Bold</string>
+									<double key="NSSize">19</double>
+									<int key="NSfFlags">16</int>
+								</object>
+								<bool key="IBUIAdjustsFontSizeToFit">NO</bool>
+							</object>
+							<object class="IBUILabel" id="277270157">
+								<reference key="NSNextResponder" ref="629468800"/>
+								<int key="NSvFlags">293</int>
+								<string key="NSFrame">{{20, 199}, {289, 53}}</string>
+								<reference key="NSSuperview" ref="629468800"/>
+								<reference key="NSWindow"/>
+								<reference key="NSNextKeyView" ref="557375485"/>
+								<string key="NSReuseIdentifierKey">_NS:9</string>
+								<reference key="IBUIBackgroundColor" ref="172308136"/>
+								<bool key="IBUIOpaque">NO</bool>
+								<bool key="IBUIClipsSubviews">YES</bool>
+								<int key="IBUIContentMode">7</int>
+								<bool key="IBUIUserInteractionEnabled">NO</bool>
+								<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
+								<string key="IBUIText">Video is playing on TV</string>
+								<object class="NSColor" key="IBUITextColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkAA</bytes>
+								</object>
+								<object class="NSColor" key="IBUIHighlightedColor">
+									<int key="NSColorSpace">1</int>
+									<bytes key="NSRGB">MC4zODAzOTIxNTY5IDAuMzgwMzkyMTU2OSAwLjM4MDM5MjE1NjkgMC44MQA</bytes>
+								</object>
+								<int key="IBUIBaselineAdjustment">0</int>
+								<int key="IBUINumberOfLines">0</int>
+								<int key="IBUITextAlignment">1</int>
+								<object class="IBUIFontDescription" key="IBUIFontDescription">
+									<int key="type">1</int>
+									<double key="pointSize">16</double>
+								</object>
+								<object class="NSFont" key="IBUIFont">
+									<string key="NSName">Helvetica</string>
+									<double key="NSSize">16</double>
+									<int key="NSfFlags">16</int>
+								</object>
+								<bool key="IBUIAdjustsFontSizeToFit">NO</bool>
+								<double key="preferredMaxLayoutWidth">289</double>
+							</object>
+						</array>
+						<string key="NSFrame">{{0, 71}, {320, 257}}</string>
+						<reference key="NSSuperview" ref="191373211"/>
+						<reference key="NSWindow"/>
+						<reference key="NSNextKeyView" ref="417847988"/>
+						<string key="NSReuseIdentifierKey">_NS:9</string>
+						<reference key="IBUIBackgroundColor" ref="172308136"/>
+						<bool key="IBUIUserInteractionEnabled">NO</bool>
+						<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
+					</object>
 					<object class="IBUIView" id="592160978">
 						<reference key="NSNextResponder" ref="191373211"/>
 						<int key="NSvFlags">269</int>
@@ -64,10 +169,7 @@
 								<reference key="NSSuperview" ref="592160978"/>
 								<reference key="NSWindow"/>
 								<reference key="NSNextKeyView" ref="949075048"/>
-								<object class="NSColor" key="IBUIBackgroundColor" id="172308136">
-									<int key="NSColorSpace">3</int>
-									<bytes key="NSWhite">MCAwAA</bytes>
-								</object>
+								<reference key="IBUIBackgroundColor" ref="172308136"/>
 								<bool key="IBUIOpaque">NO</bool>
 								<bool key="IBUIUserInteractionEnabled">NO</bool>
 								<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
@@ -274,10 +376,7 @@
 				<reference key="NSNextKeyView" ref="1066569913"/>
 				<object class="NSColor" key="IBUIBackgroundColor">
 					<int key="NSColorSpace">3</int>
-					<bytes key="NSWhite">MQA</bytes>
-					<object class="NSColorSpace" key="NSCustomColorSpace">
-						<int key="NSID">2</int>
-					</object>
+					<bytes key="NSWhite">MAA</bytes>
 				</object>
 				<object class="IBUISimulatedStatusBarMetrics" key="IBUISimulatedStatusBarMetrics"/>
 				<string key="targetRuntimeIdentifier">IBCocoaTouchFramework</string>
@@ -358,6 +457,14 @@
 					<int key="connectionID">33</int>
 				</object>
 				<object class="IBConnectionRecord">
+					<object class="IBCocoaTouchOutletConnection" key="connection">
+						<string key="label">playingExternallyView</string>
+						<reference key="source" ref="372490531"/>
+						<reference key="destination" ref="629468800"/>
+					</object>
+					<int key="connectionID">38</int>
+				</object>
+				<object class="IBConnectionRecord">
 					<object class="IBCocoaTouchEventConnection" key="connection">
 						<string key="label">togglePlayOrPause:</string>
 						<reference key="source" ref="85788192"/>
@@ -426,6 +533,7 @@
 							<reference ref="557375485"/>
 							<reference ref="1066569913"/>
 							<reference ref="592160978"/>
+							<reference ref="629468800"/>
 						</array>
 						<reference key="parent" ref="0"/>
 					</object>
@@ -529,6 +637,32 @@
 						<reference key="parent" ref="592160978"/>
 						<string key="objectName">Track Selector Button</string>
 					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">34</int>
+						<reference key="object" ref="629468800"/>
+						<array class="NSMutableArray" key="children">
+							<reference ref="277270157"/>
+							<reference ref="351293636"/>
+							<reference ref="417847988"/>
+						</array>
+						<reference key="parent" ref="191373211"/>
+						<string key="objectName">Playing Externally View</string>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">37</int>
+						<reference key="object" ref="277270157"/>
+						<reference key="parent" ref="629468800"/>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">36</int>
+						<reference key="object" ref="351293636"/>
+						<reference key="parent" ref="629468800"/>
+					</object>
+					<object class="IBObjectRecord">
+						<int key="objectID">35</int>
+						<reference key="object" ref="417847988"/>
+						<reference key="parent" ref="629468800"/>
+					</object>
 				</array>
 			</object>
 			<dictionary class="NSMutableDictionary" key="flattenedProperties">
@@ -545,6 +679,10 @@
 				<string key="15.CustomClassName">OBSlider</string>
 				<string key="15.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="27.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="34.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="35.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="36.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
+				<string key="37.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="4.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="5.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
 				<string key="6.IBPluginDependency">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
@@ -557,7 +695,7 @@
 			<nil key="activeLocalization"/>
 			<dictionary class="NSMutableDictionary" key="localizations"/>
 			<nil key="sourceID"/>
-			<int key="maxID">33</int>
+			<int key="maxID">38</int>
 		</object>
 		<object class="IBClassDescriber" key="IBDocument.Classes">
 			<array class="NSMutableArray" key="referencedPartialClassDescriptions">
@@ -621,6 +759,7 @@
 						<string key="doneBarButton">UIBarButtonItem</string>
 						<string key="movieView">UIView</string>
 						<string key="playOrPauseButton">UIButton</string>
+						<string key="playingExternallyView">UIView</string>
 						<string key="positionSlider">UISlider</string>
 						<string key="remainingTimeLabel">UIBarItem</string>
 						<string key="topView">UIView</string>
@@ -644,6 +783,10 @@
 							<string key="name">playOrPauseButton</string>
 							<string key="candidateClassName">UIButton</string>
 						</object>
+						<object class="IBToOneOutletInfo" key="playingExternallyView">
+							<string key="name">playingExternallyView</string>
+							<string key="candidateClassName">UIView</string>
+						</object>
 						<object class="IBToOneOutletInfo" key="positionSlider">
 							<string key="name">positionSlider</string>
 							<string key="candidateClassName">UISlider</string>
@@ -701,6 +844,7 @@
 			<string key="MVLCMovieViewHUDFastForward~iphone.png">{31, 23}</string>
 			<string key="MVLCMovieViewHUDPlay~iphone.png">{23, 23}</string>
 			<string key="MVLCMovieViewHUDRewind~iphone.png">{31, 23}</string>
+			<string key="MVLCNoMediaImage.png">{262, 196}</string>
 		</dictionary>
 		<string key="IBCocoaTouchPluginVersion">2083</string>
 	</data>
-- 
1.7.12.4 (Apple Git-37)

